@@ -242,7 +242,7 @@ addParTable(xtabDetails,"GenomeAxisTrack", out_type = out_type)
 if(hasUcscConnection) {
   ideoTrack <- IdeogramTrack(genome = "hg19", chromosome = "chrX")
 } else{
-  data(itrack)
+  data(ideoTrack)
 }
 plotTracks(ideoTrack, from = 85e6, to = 129e6)
 
@@ -584,7 +584,7 @@ addParTable(xtabDetails,"GeneRegionTrack", out_type = out_type)
 
 ## ----BiomartGeneRegionTrackShow, eval=FALSE-----------------------------------
 #  library(biomaRt)
-#  bm <- useMart(host = "grch37.ensembl.org",
+#  bm <- useEnsembl(host = "https://grch37.ensembl.org",
 #                biomart = "ENSEMBL_MART_ENSEMBL",
 #                dataset = "hsapiens_gene_ensembl")
 #  biomTrack <- BiomartGeneRegionTrack(genome = "hg19", chromosome = chr,
@@ -595,7 +595,7 @@ addParTable(xtabDetails,"GeneRegionTrack", out_type = out_type)
 ## ----BiomartGeneRegionTrackDo, echo=FALSE, results='hide', fig.width=7.5, fig.height=1.25----
 library(biomaRt)
 if(hasBiomartConnection) {
-  bm <- useMart(host = "grch37.ensembl.org", 
+  bm <- useEnsembl(host = "https://grch37.ensembl.org", 
                 biomart = "ENSEMBL_MART_ENSEMBL", 
                 dataset = "hsapiens_gene_ensembl")
   biomTrack <- BiomartGeneRegionTrack(genome = "hg19", chromosome = chr, 
@@ -613,7 +613,7 @@ plotTracks(biomTrack, col.line = NULL, col = NULL)
 plotTracks(biomTrack, col.line = NULL, col = NULL, stackHeight = 0.3)
 
 ## ----BiomartGeneRegionTrackFilterShow, eval=FALSE-----------------------------
-#  bm <- useMart(host = "grch37.ensembl.org",
+#  bm <- useEnsembl(host = "https://grch37.ensembl.org",
 #                biomart = "ENSEMBL_MART_ENSEMBL",
 #                dataset = "hsapiens_gene_ensembl")
 #  biomTrack <- BiomartGeneRegionTrack(genome = "hg19", chromosome = chr,
@@ -625,7 +625,7 @@ plotTracks(biomTrack, col.line = NULL, col = NULL, stackHeight = 0.3)
 
 ## ----BiomartGeneRegionTrackFilterDo, fig.width=7.5, fig.height=1.25, echo=FALSE, results='hide'----
 if(hasBiomartConnection) {
-  bm <- useMart(host = "grch37.ensembl.org",
+  bm <- useEnsembl(host = "https://grch37.ensembl.org",
                 biomart = "ENSEMBL_MART_ENSEMBL",
                 dataset = "hsapiens_gene_ensembl")
   biomTrack <- BiomartGeneRegionTrack(genome = "hg19", chromosome = chr, 
@@ -640,7 +640,7 @@ if(hasBiomartConnection) {
 }
 
 ## ----BiomartGeneRegionTrackSymbolShow, eval=FALSE-----------------------------
-#  bm <- useMart(host = "grch37.ensembl.org",
+#  bm <- useEnsembl(host = "https://grch37.ensembl.org",
 #                biomart = "ENSEMBL_MART_ENSEMBL",
 #                dataset = "hsapiens_gene_ensembl")
 #  biomTrack <- BiomartGeneRegionTrack(genome = "hg19", name = "ENSEMBL",
@@ -649,7 +649,7 @@ if(hasBiomartConnection) {
 
 ## ----BiomartGeneRegionTrackSymbolDo, fig.width=7.5, fig.height=1.25, echo=FALSE, results='hide'----
 if(hasBiomartConnection) {
-  bm <- useMart(host = "grch37.ensembl.org", 
+  bm <- useEnsembl(host = "https://grch37.ensembl.org", 
                 biomart = "ENSEMBL_MART_ENSEMBL", 
                 dataset = "hsapiens_gene_ensembl")
   biomTrack <- BiomartGeneRegionTrack(genome = "hg19", name = "ENSEMBL", 
@@ -661,7 +661,7 @@ plotTracks(biomTrack, transcriptAnnotation="symbol")
 
 ## ----BiomartGeneRegionTrackCustom, fig.width=7.5, fig.height=1.25, eval=FALSE, echo=F----
 #  library(biomaRt)
-#  bm <- useMart(host="dec2012.archive.ensembl.org", biomart="ENSEMBL_MART_ENSEMBL",
+#  bm <- useEnsembl(host="dec2012.archive.ensembl.org", biomart="ENSEMBL_MART_ENSEMBL",
 #                dataset="hsapiens_gene_ensembl")
 #  fm <- Gviz:::.getBMFeatureMap()
 #  fm[["symbol"]] <- "external_gene_id"
@@ -929,7 +929,7 @@ include_graphics("ucsc2.png")
 #                            track = "Conservation",
 #                            table = "phyloP30wayPlacental",
 #                            from = from, to = to, trackType = "DataTrack",
-#                            start = "start", end = "end", data = "score",
+#                            start = "start", end = "end", data = "value",
 #                            type = "hist", window = "auto",
 #                            col.histogram = "darkblue",
 #                            fill.histogram = "darkblue",
@@ -938,7 +938,7 @@ include_graphics("ucsc2.png")
 #  gcContent <- UcscTrack(genome = "mm9", chromosome = "chrX",
 #                         track = "GC Percent", table = "gc5Base",
 #                         from = from, to = to, trackType = "DataTrack",
-#                         start = "start", end = "end", data = "score",
+#                         start = "start", end = "end", data = "value",
 #                         type = "hist", window = -1, windowSize = 1500,
 #                         fill.histogram = "black", col.histogram = "black",
 #                         ylim = c(30, 70), name = "GC Percent")
